==> styled-bootstrap-0.1.7-1.tgz: package/lib/Alert/DismissableAlert.js <==
var _templateObject = _taggedTemplateLiteral(['\n  position: absolute;\n  top: 0;\n  right: 0;\n'], ['\n  position: absolute;\n  top: 0;\n  right: 0;\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  padding: ', '\n    ', ';\n  color: ', ';\n  ', ';\n'], ['\n  padding: ', '\n    ', ';\n  color: ', ';\n  ', ';\n']),
    _templateObject3 = _taggedTemplateLiteral(['\n  ', ';\n  padding: ', '\n    ', ';\n  cursor: pointer;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n  opacity: 0.5;\n\n  ', ';\n'], ['\n  ', ';\n  padding: ', '\n    ', ';\n  cursor: pointer;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n  opacity: 0.5;\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { cloneElement, isValidElement } from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash.omit';
import styled, { css } from 'styled-components';
import themeProp from '../utils/src/theme';
import { hoverFocus } from '../utils/src/hover';

import Alert from './Alert';
import CloseIcon from '../CLoseIcon';

import { alertPaddingY, alertPaddingX } from './default-theme';

var closeIconStyles = css(_templateObject);

export var StyledCloseIcon = styled(CloseIcon)(_templateObject2, themeProp('alertPaddingY', alertPaddingY), themeProp('alertPaddingX', alertPaddingX), function (props) {
  return !props.theme.closeColor && 'inherit';
}, closeIconStyles);

var CloseString = styled.button(_templateObject3, closeIconStyles, themeProp('alertPaddingY', alertPaddingY), themeProp('alertPaddingX', alertPaddingX), hoverFocus('\n    color: #000;\n    text-decoration: none;\n    opacity: .75;\n  '));

var DismissableAlert = function DismissableAlert(props) {
  var filteredProps = omit(props, ['onClose', 'closeIcon']);
  return React.createElement(
    Alert,
    filteredProps,
    props.children,
    props.closeIcon && isValidElement(props.closeIcon) ? cloneElement(props.closeIcon, { onClick: props.onClose }) : React.createElement(
      CloseString,
      { onClick: props.onClose },
      props.closeIcon
    ),
    !props.closeIcon && React.createElement(StyledCloseIcon, { onClick: props.onClose })
  );
};

DismissableAlert.propTypes = {
  closeIcon: PropTypes.oneOf([PropTypes.string, PropTypes.node])
};

DismissableAlert.defaultProps = {
  closeIcon: null
};

export default DismissableAlert;

==> styled-bootstrap-0.1.9.tgz: package/lib/Alert/DismissableAlert.js <==
var _templateObject = _taggedTemplateLiteral(['\n  position: absolute;\n  top: 0;\n  right: 0;\n'], ['\n  position: absolute;\n  top: 0;\n  right: 0;\n']),
    _templateObject2 = _taggedTemplateLiteral(['\n  padding: ', '\n    ', ';\n  color: ', ';\n  ', ';\n'], ['\n  padding: ', '\n    ', ';\n  color: ', ';\n  ', ';\n']),
    _templateObject3 = _taggedTemplateLiteral(['\n  ', ';\n  padding: ', '\n    ', ';\n  cursor: pointer;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n  opacity: 0.5;\n\n  ', ';\n'], ['\n  ', ';\n  padding: ', '\n    ', ';\n  cursor: pointer;\n  background: transparent;\n  border: 0;\n  -webkit-appearance: none;\n  opacity: 0.5;\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { cloneElement, isValidElement } from 'react';
import PropTypes from 'prop-types';
import omit from 'lodash.omit';
import styled, { css } from 'styled-components';
import themeProp from '../utils/theme';
import { hoverFocus } from '../utils/hover';

import Alert from './Alert';
import CloseIcon from '../CLoseIcon';

import { alertPaddingY, alertPaddingX } from './default-theme';

var closeIconStyles = css(_templateObject);

export var StyledCloseIcon = styled(CloseIcon)(_templateObject2, themeProp('alertPaddingY', alertPaddingY), themeProp('alertPaddingX', alertPaddingX), function (props) {
  return !props.theme.closeColor && 'inherit';
}, closeIconStyles);

var CloseString = styled.button(_templateObject3, closeIconStyles, themeProp('alertPaddingY', alertPaddingY), themeProp('alertPaddingX', alertPaddingX), hoverFocus('\n    color: #000;\n    text-decoration: none;\n    opacity: .75;\n  '));

var DismissableAlert = function DismissableAlert(props) {
  var filteredProps = omit(props, ['onClose', 'closeIcon']);
  return React.createElement(
    Alert,
    filteredProps,
    props.children,
    props.closeIcon && isValidElement(props.closeIcon) ? cloneElement(props.closeIcon, { onClick: props.onClose }) : React.createElement(
      CloseString,
      { onClick: props.onClose },
      props.closeIcon
    ),
    !props.closeIcon && React.createElement(StyledCloseIcon, { onClick: props.onClose })
  );
};

DismissableAlert.propTypes = {
  closeIcon: PropTypes.oneOf([PropTypes.string, PropTypes.node])
};

DismissableAlert.defaultProps = {
  closeIcon: null
};

export default DismissableAlert;
